pub struct NavigationFilter {
pub event_type_ids: Option<Vec<String>>,
pub event_type_names: Option<Vec<String>>,
pub event_ids: Option<Vec<String>>,
pub country_codes: Option<Vec<String>>,
pub market_types: Option<Vec<String>>,
pub market_ids: Option<Vec<String>>,
pub min_market_start_time: Option<String>,
pub max_market_start_time: Option<String>,
}Expand description
Filters for selecting markets from the Betfair navigation tree.
All fields use AND-logic: a market must match every provided filter.
None fields impose no constraint.
Fields
event_type_ids: Option<Vec<String>>Event type IDs to include (e.g., “7” for Horse Racing).
event_type_names: Option<Vec<String>>Event type names to include (e.g., “Horse Racing”).
event_ids: Option<Vec<String>>Event IDs to include.
country_codes: Option<Vec<String>>Country codes to include (e.g., “GB”, “AU”).
market_types: Option<Vec<String>>Market types to include (e.g., “WIN”, “PLACE”).
market_ids: Option<Vec<String>>Specific market IDs to include.
min_market_start_time: Option<String>Minimum market start time (ISO 8601 date, e.g. “2024-01-15T00:00:00Z”).
max_market_start_time: Option<String>Maximum market start time (ISO 8601 date, e.g. “2024-12-31T00:00:00Z”).
Implementations
Sourcepub fn matches(&self, market: &FlattenedMarket) -> bool
pub fn matches(&self, market: &FlattenedMarket) -> bool
Returns true if the given market passes all filter criteria.